@@ -100,11 +100,12 @@ class Domoticz(IPlugin):
 				log.msg("response   :  %s" % (jsonreq))
 				log.msg("*********************************************  : ")
 				log.msg("jsonreq.result :  %s" % (jsonreq['result']))
-				total = range (jsonreq['result'])
-				log.msg(" total    :  %s" % (total))	
+				total = len (jsonreq['result'])
+				log.msg(" total    :  %s" % (total))
+				total = iter(total)	
 				for xx in total:
-					log.msg(" jsonreq - idx   :  %s" % (xx(idx)))
-					log.msg("   jsonreq - type   :  %s" % (xx(Type)))
+					log.msg(" jsonreq - idx   :  %s" % (xx['idx']))
+					log.msg("   jsonreq - type   :  %s" % (xx['Type']))
 		if bodies == "":
 			bodies = "j'ai rien compris aux devices"
 		return {"plugin": "Domoticz",
